@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1104';
+our $VERSION = '0.1200';
 
 use Moo;
 use Music::Chord::Note;
@@ -109,6 +109,15 @@ sub cadence {
         $chord = $self->_generate_chord( $scale, $scale[0], $octave, $mtr, $mcn );
         push @$cadence, $chord;
     }
+    elsif ( $type eq 'evaded' && $self->seven ) {
+        my $chord = $self->_generate_chord( $scale, $scale[4], $octave, $mtr, $mcn );
+        $chord = $self->_invert_chord( $chord, 3, $octave );
+        push @$cadence, $chord;
+
+        $chord = $self->_generate_chord( $scale, $scale[0], $octave, $mtr, $mcn );
+        $chord = $self->_invert_chord( $chord, 1, $octave );
+        push @$cadence, $chord;
+    }
     elsif ( $type eq 'plagal' ) {
         my $chord = $self->_generate_chord( $scale, $scale[3], $octave, $mtr, $mcn );
         push @$cadence, $chord;
@@ -152,7 +161,7 @@ sub _invert_chord {
     }
     else {
         # Perform gymnastics to convert named notes to inverted named notes
-        $chord = [ grep { s/\d+// } @$chord ]
+        $chord = [ map { s/\d+//; $_ } @$chord ]
             if $octave;
 
         my $pitches = [ map { Music::Note->new( $_ . -1, 'ISO' )->format('midinum') } @$chord ];
@@ -238,7 +247,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1104
+version 0.1200
 
 =head1 SYNOPSIS
 
@@ -415,8 +424,10 @@ apply to the chords of the cadence.  For example:
 
   inversion => { 1 => 2, 2 => 1 },
 
-Says, "Apply the second inversion to the first chord of the cadence,
-and apply the first inversion to the second chord."
+This means, "Apply the second inversion to the first chord of the
+cadence, and apply the first inversion to the second chord."
+
+For seventh chords (of 4 notes), the third inversion can be applied.
 
 To B<not> apply an inversion to an inverted imperfect cadence chord,
 either do not include the numbered chord in the hash reference, or
@@ -437,10 +448,6 @@ this is:
 If an B<inversion> is defined for the C<half> cadence, the chords are
 inverted as described above for the C<imperfect> cadence.
 
-=head1 TO DO
-
-Evaded cadence
-
 =head1 SEE ALSO
 
 The F<eg/cadence>, F<t/01-methods.t> and F<t/02-methods.t> files in
